@@ -41,8 +41,12 @@ class Resource:
         else:
             self._amount = self.capacity
         self._label = label
-        self._user_records: List[Tuple[object, int | float]] = list() # (user, amount) tracking the usage of individual user
-        self._usage_records: List[Tuple[int | float, int | float]] = list() # (time, amount) tracking the usage of the resource over time
+        self._user_records: List[
+            Tuple[object, int | float]
+        ] = list()  # (user, amount) tracking the usage of individual user
+        self._usage_records: List[
+            Tuple[int | float, int | float]
+        ] = list()  # (time, amount) tracking the usage of the resource over time
 
     def get(self, amount: int | float) -> None:
         """Get the amount of resource from the resource.
@@ -52,7 +56,7 @@ class Resource:
 
         Raises:
             ValueError: raise if amount is greater than the current available amount of resource.
-        """        
+        """
         if amount > self.amount:
             raise ValueError(f"Not enough amount in Resource {self.label}.")
         else:
@@ -67,7 +71,7 @@ class Resource:
 
         Raises:
             ValueError: raise if amount is greater than the current used amount of resource.
-        """        
+        """
         if amount > self.occupied:
             raise ValueError(f"Not enough capacity in Resource {self.label}.")
         else:
@@ -83,7 +87,7 @@ class Resource:
 
         Raises:
             ValueError: raise if amount is greater than the current available amount of resource.
-        """        
+        """
         if amount > self.amount:
             raise ValueError(f"Not enough amount in Resource {self.label}.")
         else:
@@ -107,7 +111,7 @@ class Resource:
 
         Raises:
             ValueError: raise if user is not using the resource or amount is greater than the current used amount of resource.
-        """        
+        """
         if user not in self.users:
             raise ValueError(f"User {user} is not using Resource {self.label}.")
         if amount is None:
@@ -137,12 +141,12 @@ class Resource:
                         )
                         break
 
-    def usage(self, duration: int | float | Callable | None = None):
-        """Return the usage of the resource in the duration.
+    def utilization(self, duration: int | float | Callable | None = None):
+        """Return the utilization ( occupied amount / capacity ) of the resource in the duration.
 
         Args:
             duration (int | float | Callable | None, optional): the duration to trace back in time. Defaults to None.
-        """        
+        """
         if duration:
             if callable(duration):
                 after = Mundus.now - duration()
@@ -173,12 +177,22 @@ class Resource:
                             weighted_overall_amount += record[1] * (
                                 record[0] - usage_records[index - 1][0]
                             )
-                    return 1 - (
-                        weighted_overall_amount / (usage_records[-1][0] - after)
+                    return (
+                        1
+                        - (weighted_overall_amount / (usage_records[-1][0] - after))
+                        / self.capacity
                     )
         else:
             return 1 - (self.amount / self.capacity)
 
+    def usage(self, duration: int | float | Callable | None = None):
+        """Return the usage ( occupied amount ) of the resource in the duration.
+
+        Args:
+            duration (int | float | Callable | None, optional): the duration to trace back in time. Defaults to None.
+        """
+        return self.capacity * self.utilization(duration)
+
     @property
     def amount(self) -> int | float:
         """Return the current available amount of the resource."""
